..
   Template for the html base rendering

   Modified from
   https://github.com/sphinx-doc/sphinx/tree/master/sphinx/ext/autosummary/templates/autosummary/base.rst

lbfgsb.cauchy.get\_cauchy\_point
================================

.. currentmodule:: lbfgsb.cauchy

.. autofunction:: get_cauchy_point